#
# spec file for package shadowsocks-libev
#

Name:           shadowsocks-libev
Version:        3.3.5
Release:        2%{?dist}
Summary:        Libev port of Shadowsocks
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Proxy
URL:            https://github.com/shadowsocks/shadowsocks-libev
Source0:        https://github.com/shadowsocks/shadowsocks-libev/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-config.json
Source2:        %{name}-client.service
Source3:        %{name}-server.service
Source4:        %{name}-tunnel.service
Source5:        %{name}-nat.service
Source6:        %{name}-manager.service
Source7:        %{name}-redir.service
Source8:        %{name}-client@.service
Source9:        %{name}-server@.service
Source10:       %{name}-tunnel@.service
Source11:       %{name}-nat@.service
Source12:       %{name}-redir@.service
BuildRequires:  make gcc pcre-devel asciidoc xmlto automake libtool mbedtls-devel libsodium-devel >= 1.0.4 libev-devel c-ares-devel
%if 0%{?fedora} >= 24 || 0%{?rhel} >=7
BuildRequires:  pkgconfig
%else
BuildRequires:  pkg-config
%endif
BuildRequires:  pkgconfig(systemd)

%if 0%{?fedora} >= 15 || 0%{?rhel} >=7 || 0%{?suse_version} >= 1210
%global use_systemd 1
%else
%global use_systemd 0
%endif

%description
shadowsocks-libev is a lightweight secured SOCKS5 proxy for embedded devices and
low-end boxes.

%package -n lib%{name}
Summary:        Libev port of Shadowsocks
Group:          System/Libraries

%description -n lib%{name}
shadowsocks-libev is a lightweight secured SOCKS5 proxy for embedded devices and
low-end boxes.

This package provides libraries for it.

%package devel
Summary:        Development headers for shadowsocks-libev
Group:          Development/Libraries/C and C++
Requires:       lib%{name} = %{version}

%description devel
shadowsocks-libev is a lightweight secured SOCKS5 proxy for embedded devices and
low-end boxes.

This package provides development headers for it.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -fcommon"
%configure --enable-shared 

%make_build

%install
%make_install

rm -rf %{buildroot}/%{_libdir}/*.la

install -d %{buildroot}%{_sysconfdir}/shadowsocks/
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/shadowsocks/

install -d %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE3} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE4} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE5} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE6} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE7} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE8} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE9} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE10} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE11} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE12} %{buildroot}%{_unitdir}

%pre
%if 0%{?use_systemd} && 0%{?suse_version}
%service_add_pre %{name}-server.service
%endif

%post
%if ! 0%{?use_systemd}
/sbin/chkconfig --add %{name}-server > /dev/null 2>&1 || :
%else
%if 0%{?suse_version}
%service_add_post %{name}-server.service
%else
%systemd_post %{name}-server.service
%endif
%endif
setcap cap_net_bind_service+ep %{_bindir}/ss-local \
       cap_net_bind_service,cap_net_admin+ep %{_bindir}/ss-redir \
       cap_net_bind_service+ep %{_bindir}/ss-server \
       cap_net_bind_service+ep %{_bindir}/ss-tunnel

%preun
%if ! 0%{?use_systemd}
if [ $1 -eq 0 ]; then
    /sbin/service %{name}-server stop  > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}-server > /dev/null 2>&1 || :
fi
%else
%if 0%{?suse_version}
%service_del_preun %{name}-server.service
%service_del_preun %{name}-client.service
%else
%systemd_preun %{name}-server.service
%systemd_preun %{name}-client.service
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    systemctl stop %{name}-server@'*'.service  > /dev/null 2>&1 || :
    systemctl stop %{name}-client@'*'.service  > /dev/null 2>&1 || :
    systemctl stop %{name}-tunnel@'*'.service  > /dev/null 2>&1 || :
    systemctl stop %{name}-redir@'*'.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-server@.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-client@.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-tunnel@.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-redir@.service  > /dev/null 2>&1 || :
    systemctl --no-reload disable %{name}-nat@.service  > /dev/null 2>&1 || :
fi
%endif
%endif

%postun
%if 0%{?use_systemd}
%if 0%{?suse_version}
%service_del_postun %{name}-server.service
%else
%systemd_postun_with_restart %{name}-manager.service
%systemd_postun_with_restart %{name}-server.service
%systemd_postun_with_restart %{name}-client.service
%systemd_postun_with_restart %{name}-server@'*'.service
%systemd_postun_with_restart %{name}-client@'*'.service
%systemd_postun_with_restart %{name}-tunnel@'*'.service
%systemd_postun_with_restart %{name}-redir@'*'.service
%systemd_postun_with_restart %{name}-nat@'*'.service
%endif
%endif

%files
%defattr(-,root,root)
%doc Changes README.md AUTHORS
%dir %{_datadir}/doc/%{name}
%doc %{_datadir}/doc/%{name}/*.html
%dir %{_sysconfdir}/shadowsocks
%config(noreplace) %{_sysconfdir}/shadowsocks/%{name}-config.json
%license COPYING
%{_bindir}/ss-local
%{_bindir}/ss-redir
%{_bindir}/ss-server
%{_bindir}/ss-tunnel
%{_bindir}/ss-manager
%{_bindir}/ss-nat
%{_mandir}/man8/%{name}.8.gz
%{_mandir}/man1/ss-*.1.gz
%{_unitdir}/%{name}-*.service

%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/lib%{name}.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/shadowsocks.h
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so

%changelog
* Fri Jun 24 2022 Teddysun <i@teddysun.com> - 3.3.5-2
- Update version to latest commit d61d09aa0caecf31a39660f3a8f0676e53db129e
- Detect kernel support for MPTCP at runtime

* Thu Jun 16 2022 Teddysun <i@teddysun.com> - 3.3.5-1
- Update version to latest commit 01dd7df1da98710a619a4a853f6f357dfc46f60f
